==> kubernetes-model-admissionregistration-4.13.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1beta1/LocalSubjectAccessReviewFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface LocalSubjectAccessReviewFluent<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public LocalSubjectAccessReviewFluent.MetadataNested<A> withNewMetadata();
    public LocalSubjectAccessReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public LocalSubjectAccessReviewFluent.MetadataNested<A> editMetadata();
    public LocalSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadata();
    public LocalSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec getSpec();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec buildSpec();
    public A withSpec(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec spec);
    public Boolean hasSpec();
    public LocalSubjectAccessReviewFluent.SpecNested<A> withNewSpec();
    public LocalSubjectAccessReviewFluent.SpecNested<A> withNewSpecLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec item);
    public LocalSubjectAccessReviewFluent.SpecNested<A> editSpec();
    public LocalSubjectAccessReviewFluent.SpecNested<A> editOrNewSpec();
    public LocalSubjectAccessReviewFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus getStatus();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus buildStatus();
    public A withStatus(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus status);
    public Boolean hasStatus();
    public A withNewStatus(Boolean allowed,Boolean denied,String evaluationError,String reason);
    public LocalSubjectAccessReviewFluent.StatusNested<A> withNewStatus();
    public LocalSubjectAccessReviewFluent.StatusNested<A> withNewStatusLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus item);
    public LocalSubjectAccessReviewFluent.StatusNested<A> editStatus();
    public LocalSubjectAccessReviewFluent.StatusNested<A> editOrNewStatus();
    public LocalSubjectAccessReviewFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<LocalSubjectAccessReviewFluent.MetadataNested<N>> {

        public N and();
        public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<LocalSubjectAccessReviewFluent.SpecNested<N>> {

        public N and();
        public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatusFluent<LocalSubjectAccessReviewFluent.StatusNested<N>> {

        public N and();
        public N endStatus();    }


}

==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1beta1/LocalSubjectAccessReviewFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface LocalSubjectAccessReviewFluent<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.LocalSubjectAccessReviewFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public LocalSubjectAccessReviewFluent.MetadataNested<A> withNewMetadata();
    public LocalSubjectAccessReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public LocalSubjectAccessReviewFluent.MetadataNested<A> editMetadata();
    public LocalSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadata();
    public LocalSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec getSpec();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec buildSpec();
    public A withSpec(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec spec);
    public Boolean hasSpec();
    public LocalSubjectAccessReviewFluent.SpecNested<A> withNewSpec();
    public LocalSubjectAccessReviewFluent.SpecNested<A> withNewSpecLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec item);
    public LocalSubjectAccessReviewFluent.SpecNested<A> editSpec();
    public LocalSubjectAccessReviewFluent.SpecNested<A> editOrNewSpec();
    public LocalSubjectAccessReviewFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus getStatus();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus buildStatus();
    public A withStatus(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus status);
    public Boolean hasStatus();
    public A withNewStatus(Boolean allowed,Boolean denied,String evaluationError,String reason);
    public LocalSubjectAccessReviewFluent.StatusNested<A> withNewStatus();
    public LocalSubjectAccessReviewFluent.StatusNested<A> withNewStatusLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus item);
    public LocalSubjectAccessReviewFluent.StatusNested<A> editStatus();
    public LocalSubjectAccessReviewFluent.StatusNested<A> editOrNewStatus();
    public LocalSubjectAccessReviewFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<LocalSubjectAccessReviewFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<LocalSubjectAccessReviewFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatusFluent<LocalSubjectAccessReviewFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
